@@ -207,7 +207,7 @@ def test_notification_display(count_show, severity, monkeypatch):
     and warnings.showwarning... and that it emits an event which is an instance
     of napari.utils.notifications.Notification.
 
-    in `get_app()`, we connect `notification_manager.notification_ready` to
+    in `get_qapp()`, we connect `notification_manager.notification_ready` to
     `NapariQtNotification.show_notification`, so all we have to test here is
     that show_notification is capable of receiving various event types.
     (we don't need to test that )
