@@ -1,6 +1,7 @@
 import numpy as np
 
 from napari._qt.layer_controls.qt_image_controls import QtImageControls
+from napari.components.dims import Dims
 from napari.layers import Image
 
 
@@ -11,7 +12,7 @@ def test_interpolation_combobox(qtbot):
     qtbot.addWidget(qtctrl)
     combo = qtctrl.interpComboBox
     opts = {combo.itemText(i) for i in range(combo.count())}
-    assert opts == {'bicubic', 'linear', 'kaiser', 'nearest', 'spline36'}
+    assert opts == {'cubic', 'linear', 'kaiser', 'nearest', 'spline36'}
     # programmatically adding approved interpolation works
     layer.interpolation2d = 'lanczos'
     assert combo.findText('lanczos') == 5
@@ -42,8 +43,8 @@ def test_rendering_combobox(qtbot):
 def test_depiction_combobox_changes(qtbot):
     """Changing the model attribute should update the view."""
     layer = Image(np.random.rand(10, 15, 20))
-    layer._slice_dims(ndisplay=3)
     qtctrl = QtImageControls(layer)
+    qtctrl.ndisplay = 3
     qtbot.addWidget(qtctrl)
     combo_box = qtctrl.depictionComboBox
     opts = {combo_box.itemText(i) for i in range(combo_box.count())}
@@ -61,9 +62,9 @@ def test_depiction_combobox_changes(qtbot):
 def test_plane_controls_show_hide_on_depiction_change(qtbot):
     """Changing depiction mode should show/hide plane controls in 3D."""
     layer = Image(np.random.rand(10, 15, 20))
-    layer._slice_dims(ndisplay=3)
     qtctrl = QtImageControls(layer)
     qtbot.addWidget(qtctrl)
+    qtctrl.ndisplay = 3
 
     layer.depiction = 'volume'
     assert qtctrl.planeThicknessSlider.isHidden()
@@ -81,22 +82,22 @@ def test_plane_controls_show_hide_on_depiction_change(qtbot):
 def test_plane_controls_show_hide_on_ndisplay_change(qtbot):
     """Changing ndisplay should show/hide plane controls if depicting a plane."""
     layer = Image(np.random.rand(10, 15, 20))
+    layer.depiction = 'plane'
     qtctrl = QtImageControls(layer)
     qtbot.addWidget(qtctrl)
 
-    layer._slice_dims(ndisplay=3)
-    layer.depiction = 'plane'
-    assert not qtctrl.planeThicknessSlider.isHidden()
-    assert not qtctrl.planeThicknessLabel.isHidden()
-    assert not qtctrl.planeNormalButtons.isHidden()
-    assert not qtctrl.planeNormalLabel.isHidden()
-
-    layer._slice_dims(ndisplay=2)
+    assert qtctrl.ndisplay == 2
     assert qtctrl.planeThicknessSlider.isHidden()
     assert qtctrl.planeThicknessLabel.isHidden()
     assert qtctrl.planeNormalButtons.isHidden()
     assert qtctrl.planeNormalLabel.isHidden()
 
+    qtctrl.ndisplay = 3
+    assert not qtctrl.planeThicknessSlider.isHidden()
+    assert not qtctrl.planeThicknessLabel.isHidden()
+    assert not qtctrl.planeNormalButtons.isHidden()
+    assert not qtctrl.planeNormalLabel.isHidden()
+
 
 def test_plane_slider_value_change(qtbot):
     """Changing the model should update the view."""
@@ -116,19 +117,25 @@ def test_auto_contrast_buttons(qtbot):
     assert layer.contrast_limits == [0, 63]
 
     # change slice
-    layer._slice_dims((1, 8, 8))
+    dims = Dims(
+        ndim=3, range=((0, 4, 1), (0, 8, 1), (0, 8, 1)), point=(1, 8, 8)
+    )
+    layer._slice_dims(dims)
     # hasn't changed yet
     assert layer.contrast_limits == [0, 63]
 
     # with auto_btn, it should always change
     qtctrl.autoScaleBar._auto_btn.click()
     assert layer.contrast_limits == [64, 127]
-    layer._slice_dims((2, 8, 8))
+    dims.point = (2, 8, 8)
+    layer._slice_dims(dims)
     assert layer.contrast_limits == [128, 191]
-    layer._slice_dims((3, 8, 8))
+    dims.point = (3, 8, 8)
+    layer._slice_dims(dims)
     assert layer.contrast_limits == [192, 255]
 
     # once button turns off continuous
     qtctrl.autoScaleBar._once_btn.click()
-    layer._slice_dims((4, 8, 8))
+    dims.point = (4, 8, 8)
+    layer._slice_dims(dims)
     assert layer.contrast_limits == [192, 255]
