@@ -2,8 +2,7 @@ from __future__ import annotations
 
 import os
 import sys
-from contextlib import contextmanager
-from typing import TYPE_CHECKING, Optional, cast
+from typing import TYPE_CHECKING, cast
 from warnings import warn
 
 from qtpy import PYQT5, PYSIDE2
@@ -22,6 +21,7 @@ from napari._qt.utils import _maybe_allow_interrupt
 from napari.resources._icons import _theme_path
 from napari.settings import get_settings
 from napari.utils import config, perf
+from napari.utils._logging import register_logger_to_napari_handler
 from napari.utils.notifications import (
     notification_manager,
     show_console_notification,
@@ -61,11 +61,13 @@ _app_ref = None
 _IPYTHON_WAS_HERE_FIRST = 'IPython' in sys.modules
 
 
-def _focus_changed(old: Optional[QWidget], new: Optional[QWidget]):
+def _focus_changed(old: QWidget | None, new: QWidget | None):
     if old is not None and new is not None:
         return  # ignore focus changes between two widgets
     if old is None and new is None:
         return  # this should not happen
+    if not isinstance(old, QWidget):
+        return  # ignore event happened during teardown of test
     if old is None:
         start_timer = True
         window = new.window()
@@ -89,35 +91,20 @@ def _focus_changed(old: Optional[QWidget], new: Optional[QWidget]):
             notification.timer_stop()
 
 
-# TODO: Remove in napari 0.6.0
-def get_app(*args, **kwargs) -> QApplication:
-    """Get or create the Qt QApplication. Now deprecated, use `get_qapp`."""
-    warn(
-        trans._(
-            '`QApplication` instance access through `get_app` is deprecated and will be removed in 0.6.0.\n'
-            'Please use `get_qapp` instead.\n',
-            deferred=True,
-        ),
-        category=FutureWarning,
-        stacklevel=2,
-    )
-    return get_qapp(*args, **kwargs)
-
-
 def get_qapp(
     *,
-    app_name: Optional[str] = None,
-    app_version: Optional[str] = None,
-    icon: Optional[str] = None,
-    org_name: Optional[str] = None,
-    org_domain: Optional[str] = None,
-    app_id: Optional[str] = None,
-    ipy_interactive: Optional[bool] = None,
+    app_name: str | None = None,
+    app_version: str | None = None,
+    icon: str | None = None,
+    org_name: str | None = None,
+    org_domain: str | None = None,
+    app_id: str | None = None,
+    ipy_interactive: bool | None = None,
 ) -> QApplication:
     """Get or create the Qt QApplication.
 
     There is only one global QApplication instance, which can be retrieved by
-    calling get_app again, (or by using QApplication.instance())
+    calling get_qapp, (or by using QApplication.instance())
 
     Parameters
     ----------
@@ -165,7 +152,7 @@ def get_qapp(
         if set_values:
             warn(
                 trans._(
-                    "QApplication already existed, these arguments to to 'get_app' were ignored: {args}",
+                    "QApplication already existed, these arguments to to 'get_qapp' were ignored: {args}",
                     deferred=True,
                     args=set_values,
                 ),
@@ -235,7 +222,7 @@ def get_qapp(
         # Will patch based on config file.
         perf_config.patch_callables()
 
-    if not _app_ref:  # running get_app for the first time
+    if not _app_ref:  # running for first time
         # see docstring of `wait_for_workers_to_quit` for caveats on killing
         # workers at shutdown.
         app.aboutToQuit.connect(wait_for_workers_to_quit)
@@ -302,53 +289,6 @@ def quit_app():
         monitor.stop()
 
 
-@contextmanager
-def gui_qt(*, startup_logo=False, gui_exceptions=False, force=False):
-    """Start a Qt event loop in which to run the application.
-
-    NOTE: This context manager is deprecated!. Prefer using :func:`napari.run`.
-
-    Parameters
-    ----------
-    startup_logo : bool, optional
-        Show a splash screen with the napari logo during startup.
-    gui_exceptions : bool, optional
-        Whether to show uncaught exceptions in the GUI, by default they will be
-        shown in the console that launched the event loop.
-    force : bool, optional
-        Force the application event_loop to start, even if there are no top
-        level widgets to show.
-
-    Notes
-    -----
-    This context manager is not needed if running napari within an interactive
-    IPython session. In this case, use the ``%gui qt`` magic command, or start
-    IPython with the Qt GUI event loop enabled by default by using
-    ``ipython --gui=qt``.
-    """
-    warn(
-        trans._(
-            "\nThe 'gui_qt()' context manager is deprecated.\nIf you are running napari from a script, please use 'napari.run()' as follows:\n\n    import napari\n\n    viewer = napari.Viewer()  # no prior setup needed\n    # other code using the viewer...\n    napari.run()\n\nIn IPython or Jupyter, 'napari.run()' is not necessary. napari will automatically\nstart an interactive event loop for you: \n\n    import napari\n    viewer = napari.Viewer()  # that's it!\n",
-            deferred=True,
-        ),
-        FutureWarning,
-        stacklevel=2,
-    )
-
-    app = get_app()
-    splash = None
-    if startup_logo and app.applicationName() == 'napari':
-        from napari._qt.widgets.qt_splash_screen import NapariSplashScreen
-
-        splash = NapariSplashScreen()
-        splash.close()
-    try:
-        yield app
-    except Exception:  # noqa: BLE001
-        notification_manager.receive_error(*sys.exc_info())
-    run(force=force, gui_exceptions=gui_exceptions, _func_name='gui_qt')
-
-
 def _ipython_has_eventloop() -> bool:
     """Return True if IPython %gui qt is active.
 
@@ -413,8 +353,8 @@ def run(
         This function will prevent calling `exec_()` if the application already
         has at least ``max_loop_level`` event loops running.  By default, 1.
     _func_name : str, optional
-        name of calling function, by default 'run'.  This is only here to
-        provide functions like `gui_qt` a way to inject their name into the
+        name of calling function, by default 'run'.  This is here to
+        provide functions a way to inject their name into the
         warning message.
 
     Raises
@@ -436,7 +376,7 @@ def run(
     if not app:
         raise RuntimeError(
             trans._(
-                'No Qt app has been created. One can be created by calling `get_app()` or `qtpy.QtWidgets.QApplication([])`',
+                'No Qt app has been created. One can be created by calling `get_qapp()` or `qtpy.QtWidgets.QApplication([])`',
                 deferred=True,
             )
         )
@@ -465,5 +405,9 @@ def run(
             stacklevel=2,
         )
         return
-    with notification_manager, _maybe_allow_interrupt(app):
+    with (
+        notification_manager,
+        _maybe_allow_interrupt(app),
+        register_logger_to_napari_handler(''),
+    ):
         app.exec_()
