@@ -598,8 +598,12 @@ class QtViewer(QSplitter):
                 # `set_data` notifies the corresponding vispy layer of the new
                 # slice.
                 layer.events.set_data()
-                layer._update_thumbnail()
-                layer._set_highlight(force=True)
+                layer._refresh_sync(
+                    data_displayed=False,
+                    thumbnail=True,
+                    highlight=True,
+                    extent=True,
+                )
 
     def _on_active_change(self):
         """When active layer changes change keymap handler."""
