@@ -70,9 +70,10 @@ def test_add_dock_widget_raises(make_napari_viewer):
         viewer.window.add_dock_widget(widg, name='test')
 
 
-def test_remove_dock_widget_orphans_widget(make_napari_viewer):
+def test_remove_dock_widget_orphans_widget(make_napari_viewer, qtbot):
     viewer = make_napari_viewer()
     widg = QPushButton('button')
+    qtbot.addWidget(widg)
 
     assert not widg.parent()
     dw = viewer.window.add_dock_widget(
@@ -87,9 +88,10 @@ def test_remove_dock_widget_orphans_widget(make_napari_viewer):
     assert not widg.parent()
 
 
-def test_remove_dock_widget_by_widget_reference(make_napari_viewer):
+def test_remove_dock_widget_by_widget_reference(make_napari_viewer, qtbot):
     viewer = make_napari_viewer()
     widg = QPushButton('button')
+    qtbot.addWidget(widg)
 
     dw = viewer.window.add_dock_widget(widg, name='test')
     assert widg.parent() is dw
