@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Optional
-
 import numpy as np
 from vispy.scene.widgets.viewbox import ViewBox
 
@@ -127,7 +125,7 @@ def get_view_direction_in_scene_coordinates(
     view: ViewBox,
     ndim: int,
     dims_displayed: tuple[int],
-) -> Optional[np.ndarray]:
+) -> np.ndarray | None:
     """Calculate the unit vector pointing in the direction of the view.
 
     This is only for 3D viewing, so it returns None when
