@@ -834,7 +834,7 @@ class Layer(KeymapProvider, MousemapProvider, ABC, metaclass=PostInit):
         return self._transforms['data2physical'].units
 
     @units.setter
-    def units(self, units: Sequence[pint.Unit] | None) -> None:
+    def units(self, units: Sequence[pint.Unit | str] | None) -> None:
         prev = self.units
         # mypy bug https://github.com/python/mypy/issues/3004
         self._transforms['data2physical'].units = units  # type: ignore[assignment]
@@ -1526,7 +1526,9 @@ class Layer(KeymapProvider, MousemapProvider, ABC, metaclass=PostInit):
             return
         logger.debug('Layer.refresh: %s', self)
         # If async is enabled then emit an event that the viewer should handle.
-        if get_settings().experimental.async_:
+        if get_settings().experimental.async_ and data_displayed:
+            # full async slice reload, it will also update everything when done slicing
+            # via the callback of layer.loaded which calls _refresh_sync
             self.events.reload(layer=self)
         # Otherwise, slice immediately on the calling thread.
         else:
