@@ -925,7 +925,7 @@ def normalize_vertices_and_edges(
     if (
         vertices[0, 0] == vertices[-1, 0] and vertices[0, 1] == vertices[-1, 1]
     ):  # closed polygon
-        vertices = vertices[:-1]  # make closing implicit
+        vertices = vertices[:-1]  # type: ignore[assignment] # make closing implicit
         close = True
     # Now, we make sure the vertices are unique (repeated vertices cause
     # problems in spatial algorithms, and those problems can manifest as
@@ -969,4 +969,4 @@ def normalize_vertices_and_edges(
     for i, vertex in enumerate(new_vertices):
         new_vertices_array[i] = vertex
     edges_array = np.array(list(edges), dtype=np.int64)
-    return new_vertices_array, edges_array
+    return new_vertices_array, edges_array  # type: ignore[return-value]
