@@ -279,13 +279,15 @@ def reconstruct_polygons_from_edges_py(
     """
     # Create an adjacency list representation from the edges
     adjacency = defaultdict(list)
-    for edge in edges:
-        v1, v2 = edge
+    for edge_ in edges:
+        v1, v2 = edge_
         adjacency[v1].append(v2)
         adjacency[v2].append(v1)
 
     # Initialize set of unvisited edges
-    unvisited_edges = {(edge[0], edge[1]) for edge in edges}
+    unvisited_edges: set[tuple[int, int]] = {
+        (edge[0], edge[1]) for edge in edges
+    }
     unvisited_edges.update({(edge[1], edge[0]) for edge in edges})
 
     # List to store resulting polygons
@@ -294,7 +296,7 @@ def reconstruct_polygons_from_edges_py(
     # Process each edge until all are visited
     while unvisited_edges:
         # Start with any unvisited edge
-        edge = next(iter(unvisited_edges))
+        edge: tuple[int, int] = next(iter(unvisited_edges))
         current_vertex = edge[0]
         start_vertex = edge[1]
 
@@ -328,7 +330,7 @@ def reconstruct_polygons_from_edges_py(
         polygon_vertices = vertices[polygon_indices]
         polygons.append(polygon_vertices)
 
-    return polygons
+    return polygons  # type: ignore[return-value]
 
 
 def normalize_vertices_and_edges_py(
@@ -373,7 +375,7 @@ def normalize_vertices_and_edges_py(
         that are visited twice are removed.
     """
     if tuple(vertices[0]) == tuple(vertices[-1]):  # closed polygon
-        vertices = vertices[:-1]  # make closing implicit
+        vertices = vertices[:-1]  # type: ignore[assignment] # make closing implicit
         close = True
 
     # Now, we make sure the vertices are unique (repeated vertices cause
@@ -385,7 +387,7 @@ def normalize_vertices_and_edges_py(
     prev_idx = 0
     i = 0
     for vertex in vertices:
-        vertex_t = tuple(vertex)
+        vertex_t = vertex[0], vertex[1]
         current_idx = vertex_to_idx.setdefault(vertex_t, i)
         if current_idx == i:
             new_vertices.append(vertex)
@@ -416,7 +418,7 @@ def normalize_vertices_and_edges_py(
 
     new_vertices_array = np.array(new_vertices, dtype=np.float32)
     edges_array = np.array(list(edges), dtype=np.int64)
-    return new_vertices_array, edges_array
+    return new_vertices_array, edges_array  # type: ignore[return-value]
 
 
 def _are_polar_angles_monotonic(poly: npt.NDArray, orientation_: int) -> bool:
