@@ -1,13 +1,13 @@
 import numpy as np
 from scipy.interpolate import splev, splprep
 
+from napari.layers.shapes._accelerated_triangulate_dispatch import (
+    create_box_from_bounding,
+)
 from napari.layers.shapes._shapes_models.shape import (
     Shape,
     remove_path_duplicates,
 )
-from napari.layers.shapes._shapes_utils import (
-    create_box_from_bounding,
-)
 from napari.utils.translations import trans
 
 
@@ -112,7 +112,7 @@ class PolygonBase(Shape):
             if len(data_spline) > self.interpolation_order:
                 data = data_spline.copy()
                 if self._closed:
-                    data = np.append(data, data[:1], axis=0)
+                    data = np.append(data, data[:1], axis=0)  # type: ignore[assignment]
 
                 tck, *_ = splprep(
                     data.T, s=0, k=self.interpolation_order, per=self._closed
@@ -123,7 +123,7 @@ class PolygonBase(Shape):
                 u = np.linspace(0, 1, self.interpolation_sampling * len(data))
 
                 # get interpolated data (discard last element which is a copy)
-                data = np.stack(splev(u, tck), axis=1)[:-1].astype(np.float32)
+                data = np.stack(splev(u, tck), axis=1)[:-1].astype(np.float32)  # type: ignore[assignment]
 
         # For path connect every all data
         self._set_meshes(data, face=self._filled, closed=self._closed)
