@@ -16,6 +16,7 @@ from napari.layers.shapes import (
     _accelerated_triangulate_python as _triangulate_py,
 )
 from napari.layers.shapes.shape_types import (
+    BoxArray,
     CoordinateArray,
     CoordinateArray2D,
     CoordinateArray3D,
@@ -35,8 +36,8 @@ except ModuleNotFoundError:
 
 
 def find_planar_axis(
-    points: npt.NDArray,
-) -> tuple[npt.NDArray, int | None, float | None]:
+    points: CoordinateArray,
+) -> tuple[CoordinateArray2D, int | None, float | None]:
     """Find an axis along which the input points are planar.
 
     If points are 2D, they are returned unchanged.
@@ -63,27 +64,41 @@ def find_planar_axis(
     """
     ndim = points.shape[1]
     if ndim == 2:
-        return points, None, None
+        return points, None, None  # type: ignore[return-value]
     for axis_idx in range(ndim):
         values = np.unique(points[:, axis_idx])
         if len(values) == 1:
-            return np.delete(points, axis_idx, axis=1), axis_idx, values[0]
-    return np.empty((0, 2), dtype=points.dtype), None, None
+            return np.delete(points, axis_idx, axis=1), axis_idx, values[0]  # type: ignore[return-value]
+    return np.empty((0, 2), dtype=points.dtype), None, None  # type: ignore[return-value]
 
 
-def _fan_triangulation(poly: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
+@typing.overload
+def _fan_triangulation(
+    poly: CoordinateArray2D,
+) -> tuple[CoordinateArray2D, TriangleArray]: ...
+
+
+@typing.overload
+def _fan_triangulation(
+    poly: CoordinateArray3D,
+) -> tuple[CoordinateArray3D, TriangleArray]: ...
+
+
+def _fan_triangulation(
+    poly: CoordinateArray,
+) -> tuple[CoordinateArray, TriangleArray]:
     """Return a fan triangulation of a given polygon.
 
     https://en.wikipedia.org/wiki/Fan_triangulation
 
     Parameters
     ----------
-    poly: numpy array of float, shape (N, 3)
+    poly: numpy array of float, shape (N, 3) or (N, 2)
         Polygon vertices, in order.
 
     Returns
     -------
-    vertices : numpy array of float, shape (N, 3)
+    vertices : numpy array of float, shape (N, 3) or (N, 2)
         The vertices of the triangulation. In this case, the input array.
     triangles : numpy array of int, shape (N, 3)
         The triangles of the triangulation, as triplets of indices into the
@@ -93,7 +108,7 @@ def _fan_triangulation(poly: npt.NDArray) -> tuple[npt.NDArray, npt.NDArray]:
     triangles = np.zeros((len(poly) - 2, 3), dtype=np.uint32)
     triangles[:, 1] = np.arange(1, len(poly) - 1)
     triangles[:, 2] = np.arange(2, len(poly))
-    return vertices, triangles
+    return vertices, triangles  # type: ignore[return-value]
 
 
 def inside_boxes(boxes):
@@ -380,7 +395,7 @@ def point_to_lines(point, lines):
     return index, location
 
 
-def create_box(data: npt.NDArray) -> npt.NDArray:
+def create_box(data: CoordinateArray2D) -> BoxArray:
     """Creates the axis aligned interaction box of a list of points
 
     Parameters
@@ -414,10 +429,12 @@ def create_box(data: npt.NDArray) -> npt.NDArray:
             (tl + tr + br + bl) / 4,
         ]
     )
-    return box
+    return box  # type: ignore[return-value]
 
 
-def rectangle_to_box(data: npt.NDArray) -> npt.NDArray:
+def rectangle_to_box(
+    data: np.ndarray[tuple[typing.Literal[4], int], np.dtype[np.float32]],
+) -> BoxArray:
     """Converts the four corners of a rectangle into a interaction box like
     representation. If the rectangle is not axis aligned the resulting box
     representation will not be axis aligned either
@@ -454,7 +471,7 @@ def rectangle_to_box(data: npt.NDArray) -> npt.NDArray:
             data.mean(axis=0),
         ]
     )
-    return box
+    return box  # type: ignore[return-value]
 
 
 def find_corners(data: npt.NDArray) -> npt.NDArray:
@@ -504,8 +521,8 @@ def center_radii_to_corners(
 
 
 def triangulate_ellipse(
-    corners: npt.NDArray, num_segments: int = 100
-) -> tuple[npt.NDArray, npt.NDArray]:
+    corners: CoordinateArray, num_segments: int = 100
+) -> tuple[CoordinateArray, TriangleArray]:
     """Determines the triangulation of a path. The resulting `offsets` can
     multiplied by a `width` scalar and be added to the resulting `centers`
     to generate the vertices of the triangles for the triangulation, i.e.
@@ -647,14 +664,15 @@ def _fix_vertices_if_needed(
     if axis is None or value is None:
         return vertices
     new_vertices = np.insert(vertices, axis, value, axis=1)
-    return new_vertices
+    return new_vertices  # type: ignore[return-value]
 
 
 def triangulate_face_and_edges(
     polygon_vertices: CoordinateArray,
     triangulate_face_: typing.Callable,
 ) -> tuple[
-    tuple[np.ndarray, np.ndarray], tuple[np.ndarray, np.ndarray, np.ndarray]
+    tuple[CoordinateArray, TriangleArray],
+    tuple[CoordinateArray, CoordinateArray, TriangleArray],
 ]:
     """Determines the triangulation of the face and edges of a shape.
 
@@ -678,7 +696,7 @@ def triangulate_face_and_edges(
             np.empty((0, 3), dtype=np.int32),
         )
         edge_tri = triangulate_edge(polygon_vertices, closed=True)
-        return face_tri, edge_tri
+        return face_tri, edge_tri  # type: ignore[return-value]
 
     if _triangulate_dispatch.is_convex(data2d):
         vertices, triangles = _fan_triangulation(data2d)
@@ -756,7 +774,7 @@ def reconstruct_and_triangulate_edge(
         offset_list.append(offset)
         triangles_list.append(triangles + offset_idx)
         offset_idx += len(centers)
-    return (
+    return (  # type: ignore[return-value]
         np.concatenate(centers_list),
         np.concatenate(offset_list),
         np.concatenate(triangles_list),
