@@ -527,7 +527,10 @@ def test_rectangles_with_shape_type(ten_four_corner: list[np.ndarray]):
     layer = Shapes(data)
     assert layer.nshapes == len(ten_four_corner)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_four_corner)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_four_corner, strict=False)
+        ]
     )
     assert layer.ndim == ten_four_corner[0].shape[1]
     assert np.all([s == 'rectangle' for s in layer.shape_type])
@@ -541,7 +544,10 @@ def test_rectangles_with_shape_type_per_element(
     layer = Shapes(data)
     assert layer.nshapes == len(ten_four_corner)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_four_corner)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_four_corner, strict=False)
+        ]
     )
     assert layer.ndim == ten_four_corner[0].shape[1]
     assert np.all([s == 'rectangle' for s in layer.shape_type])
@@ -554,7 +560,9 @@ def test_rectangles_roundtrip():
     data = 20 * np.random.random(shape)
     layer = Shapes(data)
     new_layer = Shapes(layer.data)
-    assert np.all([nd == d for nd, d in zip(new_layer.data, layer.data)])
+    assert np.all(
+        [nd == d for nd, d in zip(new_layer.data, layer.data, strict=False)]
+    )
 
 
 def test_integer_rectangle():
@@ -574,7 +582,12 @@ def test_negative_rectangle(ten_four_corner):
     data = [x - 10 for x in ten_four_corner]
     layer = Shapes(data)
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == data[0].shape[1]
     assert np.all([s == 'rectangle' for s in layer.shape_type])
 
@@ -598,7 +611,12 @@ def test_3D_rectangles():
     data = np.concatenate((planes, corners), axis=2, dtype=np.float32)
     layer = Shapes(data)
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == 3
     assert np.all([s == 'rectangle' for s in layer.shape_type])
 
@@ -607,7 +625,10 @@ def test_3D_rectangles():
     layer2.add_rectangles(data)
     assert layer2.nshapes == layer.nshapes
     assert np.all(
-        [np.array_equal(ld, ld2) for ld, ld2 in zip(layer.data, layer2.data)]
+        [
+            np.array_equal(ld, ld2)
+            for ld, ld2 in zip(layer.data, layer2.data, strict=False)
+        ]
     )
     assert np.all([s == 'rectangle' for s in layer2.shape_type])
 
@@ -674,7 +695,10 @@ def test_ten_ellipses_with_shape_type(ten_four_corner):
     layer = Shapes(data)
     assert layer.nshapes == len(ten_four_corner)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_four_corner)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_four_corner, strict=False)
+        ]
     )
     assert layer.ndim == ten_four_corner[0].shape[1]
     assert np.all([s == 'ellipse' for s in layer.shape_type])
@@ -686,7 +710,10 @@ def test_ten_ellipses_with_shape_type_per_shape(ten_four_corner):
     layer = Shapes(data)
     assert layer.nshapes == len(ten_four_corner)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_four_corner)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_four_corner, strict=False)
+        ]
     )
     assert layer.ndim == ten_four_corner[0].shape[1]
     assert np.all([s == 'ellipse' for s in layer.shape_type])
@@ -736,7 +763,12 @@ def test_4D_ellispse():
     ]
     layer = Shapes(data, shape_type='ellipse')
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == 4
     assert np.all([s == 'ellipse' for s in layer.shape_type])
 
@@ -745,7 +777,10 @@ def test_4D_ellispse():
     layer2.add_ellipses(data)
     assert layer.nshapes == layer2.nshapes
     assert np.all(
-        [np.array_equal(ld, ld2) for ld, ld2 in zip(layer.data, layer2.data)]
+        [
+            np.array_equal(ld, ld2)
+            for ld, ld2 in zip(layer.data, layer2.data, strict=False)
+        ]
     )
     assert layer.ndim == 4
     assert np.all([s == 'ellipse' for s in layer2.shape_type])
@@ -758,7 +793,9 @@ def test_ellipses_roundtrip():
     data = 20 * np.random.random(shape)
     layer = Shapes(data, shape_type='ellipse')
     new_layer = Shapes(layer.data, shape_type='ellipse')
-    assert np.all([nd == d for nd, d in zip(new_layer.data, layer.data)])
+    assert np.all(
+        [nd == d for nd, d in zip(new_layer.data, layer.data, strict=False)]
+    )
 
 
 def test_lines(two_corners):
@@ -767,7 +804,10 @@ def test_lines(two_corners):
     layer = Shapes(two_corners, shape_type='line')
     assert layer.nshapes == len(two_corners)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, two_corners)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, two_corners, strict=False)
+        ]
     )
     assert layer.ndim == two_corners[0].shape[1]
     assert np.all([s == 'line' for s in layer.shape_type])
@@ -818,7 +858,10 @@ def test_ten_lines_with_shape_type(ten_two_corners):
     layer = Shapes(data)
     assert layer.nshapes == len(ten_two_corners)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_two_corners)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_two_corners, strict=False)
+        ]
     )
     assert layer.ndim == ten_two_corners[0].shape[1]
     assert np.all([s == 'line' for s in layer.shape_type])
@@ -830,7 +873,10 @@ def test_ten_lines_with_shape_type_per_shape(ten_two_corners):
     layer = Shapes(data)
     assert layer.nshapes == len(ten_two_corners)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_two_corners)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_two_corners, strict=False)
+        ]
     )
     assert layer.ndim == ten_two_corners[0].shape[1]
     assert np.all([s == 'line' for s in layer.shape_type])
@@ -843,7 +889,9 @@ def test_lines_roundtrip():
     data = 20 * np.random.random(shape)
     layer = Shapes(data, shape_type='line')
     new_layer = Shapes(layer.data, shape_type='line')
-    assert np.all([nd == d for nd, d in zip(new_layer.data, layer.data)])
+    assert np.all(
+        [nd == d for nd, d in zip(new_layer.data, layer.data, strict=False)]
+    )
 
 
 @pytest.mark.parametrize(
@@ -865,7 +913,12 @@ def test_paths(shape):
     data = [20 * np.random.random(shape).astype(np.float32)]
     layer = Shapes(data, shape_type='path')
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == 2
     assert np.all([s == 'path' for s in layer.shape_type])
 
@@ -915,7 +968,10 @@ def test_paths_with_shape_type():
     layer = Shapes(data)
     assert layer.nshapes == len(path_points)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, path_points)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, path_points, strict=False)
+        ]
     )
     assert layer.ndim == 2
     assert np.all([s == 'path' for s in layer.shape_type])
@@ -925,7 +981,10 @@ def test_paths_with_shape_type():
     layer = Shapes(data)
     assert layer.nshapes == len(data)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, path_points)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, path_points, strict=False)
+        ]
     )
     assert layer.ndim == 2
     assert np.all([s == 'path' for s in layer.shape_type])
@@ -940,7 +999,10 @@ def test_paths_roundtrip():
     layer = Shapes(data, shape_type='path')
     new_layer = Shapes(layer.data, shape_type='path')
     assert np.all(
-        [np.array_equal(nd, d) for nd, d in zip(new_layer.data, layer.data)]
+        [
+            np.array_equal(nd, d)
+            for nd, d in zip(new_layer.data, layer.data, strict=False)
+        ]
     )
 
 
@@ -963,7 +1025,12 @@ def test_polygons(shape):
     data = [20 * np.random.random(shape).astype(np.float32)]
     layer = Shapes(data, shape_type='polygon')
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == 2
     assert np.all([s == 'polygon' for s in layer.shape_type])
 
@@ -1034,7 +1101,10 @@ def test_polygons_with_shape_type():
     layer = Shapes(data)
     assert layer.nshapes == len(polygons)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, polygons)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, polygons, strict=False)
+        ]
     )
     assert layer.ndim == 2
     assert np.all([s == 'polygon' for s in layer.shape_type])
@@ -1044,7 +1114,10 @@ def test_polygons_with_shape_type():
     layer = Shapes(data)
     assert layer.nshapes == len(polygons)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, polygons)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, polygons, strict=False)
+        ]
     )
     assert layer.ndim == 2
     assert np.all([s == 'polygon' for s in layer.shape_type])
@@ -1059,7 +1132,10 @@ def test_polygon_roundtrip():
     layer = Shapes(data, shape_type='polygon')
     new_layer = Shapes(layer.data, shape_type='polygon')
     assert np.all(
-        [np.array_equal(nd, d) for nd, d in zip(new_layer.data, layer.data)]
+        [
+            np.array_equal(nd, d)
+            for nd, d in zip(new_layer.data, layer.data, strict=False)
+        ]
     )
 
 
@@ -1075,18 +1151,31 @@ def test_mixed_shapes():
     layer = Shapes(shape_vertices, shape_type=shape_type)
     assert layer.nshapes == len(shape_vertices)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, shape_vertices)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, shape_vertices, strict=False)
+        ]
     )
     assert layer.ndim == 2
-    assert np.all([s == so for s, so in zip(layer.shape_type, shape_type)])
+    assert np.all(
+        [s == so for s, so in zip(layer.shape_type, shape_type, strict=False)]
+    )
 
     # Test roundtrip with mixed data
     new_layer = Shapes(layer.data, shape_type=layer.shape_type)
     assert np.all(
-        [np.array_equal(nd, d) for nd, d in zip(new_layer.data, layer.data)]
+        [
+            np.array_equal(nd, d)
+            for nd, d in zip(new_layer.data, layer.data, strict=False)
+        ]
     )
     assert np.all(
-        [ns == s for ns, s in zip(new_layer.shape_type, layer.shape_type)]
+        [
+            ns == s
+            for ns, s in zip(
+                new_layer.shape_type, layer.shape_type, strict=False
+            )
+        ]
     )
 
 
@@ -1100,14 +1189,19 @@ def test_mixed_shapes_with_shape_type():
     shape_type = ['polygon'] * 5 + ['rectangle'] * 3 + ['ellipse'] * 2
 
     # Test multiple (shape, shape_type) tuples
-    data = list(zip(shape_vertices, shape_type))
+    data = list(zip(shape_vertices, shape_type, strict=False))
     layer = Shapes(data)
     assert layer.nshapes == len(shape_vertices)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, shape_vertices)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, shape_vertices, strict=False)
+        ]
     )
     assert layer.ndim == 2
-    assert np.all([s == so for s, so in zip(layer.shape_type, shape_type)])
+    assert np.all(
+        [s == so for s, so in zip(layer.shape_type, shape_type, strict=False)]
+    )
 
 
 def test_data_shape_type_overwrites_meta():
@@ -1133,7 +1227,7 @@ def test_changing_shapes(ten_four_corner, twenty_four_corner):
     assert np.all(
         [
             np.array_equal(ld, d)
-            for ld, d in zip(layer.data, twenty_four_corner)
+            for ld, d in zip(layer.data, twenty_four_corner, strict=False)
         ]
     )
     assert layer.ndim == twenty_four_corner[0].shape[1]
@@ -1144,7 +1238,10 @@ def test_changing_shapes(ten_four_corner, twenty_four_corner):
     layer.data = data_a
     assert layer.nshapes == len(ten_four_corner)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, ten_four_corner)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, ten_four_corner, strict=False)
+        ]
     )
     assert layer.ndim == ten_four_corner[0].shape[1]
     assert np.all([s == 'ellipse' for s in layer.shape_type])
@@ -1198,26 +1295,42 @@ def test_adding_shapes(polygons, ten_four_corner):
     all_shape_type = ['polygon'] * len(polygons) + new_shape_type
     assert layer.nshapes == len(all_data)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, all_data)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, all_data, strict=False)
+        ]
     )
     assert layer.ndim == 2
-    assert np.all([s == so for s, so in zip(layer.shape_type, all_shape_type)])
+    assert np.all(
+        [
+            s == so
+            for s, so in zip(layer.shape_type, all_shape_type, strict=False)
+        ]
+    )
 
 
 def test_adding_shapes_per_shape(polygons, ten_four_corner):
     # test adding data with shape_type
     layer = Shapes(polygons, shape_type='polygon')
     new_shape_type = ['ellipse'] * 6 + ['rectangle'] * 4
-    new_data = list(zip(ten_four_corner, new_shape_type))
+    new_data = list(zip(ten_four_corner, new_shape_type, strict=False))
     layer.add(new_data)
     all_vertices = polygons + ten_four_corner
     all_shape_type = ['polygon'] * len(polygons) + new_shape_type
     assert layer.nshapes == len(all_vertices)
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, all_vertices)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, all_vertices, strict=False)
+        ]
     )
     assert layer.ndim == 2
-    assert np.all([s == so for s, so in zip(layer.shape_type, all_shape_type)])
+    assert np.all(
+        [
+            s == so
+            for s, so in zip(layer.shape_type, all_shape_type, strict=False)
+        ]
+    )
 
 
 def test_adding_shapes_to_empty():
@@ -1235,9 +1348,16 @@ def test_adding_shapes_to_empty():
 
     layer.add(data, shape_type=shape_type)
     assert layer.nshapes == len(data)
-    assert np.all([np.array_equal(ld, d) for ld, d in zip(layer.data, data)])
+    assert np.all(
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data, strict=False)
+        ]
+    )
     assert layer.ndim == 2
-    assert np.all([s == so for s, so in zip(layer.shape_type, shape_type)])
+    assert np.all(
+        [s == so for s, so in zip(layer.shape_type, shape_type, strict=False)]
+    )
 
 
 def test_selecting_shapes():
@@ -1348,11 +1468,17 @@ def test_removing_selected_shapes():
     assert len(layer.data) == len(data_keep)
     assert len(layer.selected_data) == 0
     assert np.all(
-        [np.array_equal(ld, d) for ld, d in zip(layer.data, data_keep)]
+        [
+            np.array_equal(ld, d)
+            for ld, d in zip(layer.data, data_keep, strict=False)
+        ]
     )
     assert layer.ndim == 2
     assert np.all(
-        [s == so for s, so in zip(layer.shape_type, shape_type_keep)]
+        [
+            s == so
+            for s, so in zip(layer.shape_type, shape_type_keep, strict=False)
+        ]
     )
 
 
@@ -2036,14 +2162,20 @@ def test_copy_and_paste():
     assert len(layer._clipboard) > 0
     assert len(layer.data) == shape[0] + 2
     assert np.all(
-        [np.array_equal(a, b) for a, b in zip(layer.data[:2], layer.data[-2:])]
+        [
+            np.array_equal(a, b)
+            for a, b in zip(layer.data[:2], layer.data[-2:], strict=False)
+        ]
     )
 
     # Pasting again adds two more shapes to data
     layer._paste_data()
     assert len(layer.data) == shape[0] + 4
     assert np.all(
-        [np.array_equal(a, b) for a, b in zip(layer.data[:2], layer.data[-2:])]
+        [
+            np.array_equal(a, b)
+            for a, b in zip(layer.data[:2], layer.data[-2:], strict=False)
+        ]
     )
 
     # Unselecting everything and copying and pasting will empty the clipboard
