@@ -2,7 +2,7 @@
 # from napari.utils.events import Event
 # from napari.utils.colormaps import AVAILABLE_COLORMAPS
 
-from typing import Any, Optional, Union
+from typing import Any
 from warnings import warn
 
 import numpy as np
@@ -179,7 +179,7 @@ class Tracks(Layer):
         # track manager deals with data slicing, graph building and properties
         self._manager = TrackManager(data)
 
-        self._track_colors: Optional[np.ndarray] = None
+        self._track_colors: np.ndarray | None = None
         self._colormaps_dict = colormaps_dict or {}  # additional colormaps
         self._color_by = color_by  # default color by ID
         self._colormap = colormap
@@ -228,7 +228,7 @@ class Tracks(Layer):
         else:
             maxs = np.max(self.data, axis=0)
             mins = np.min(self.data, axis=0)
-            extrema = np.vstack([mins, maxs])
+            extrema = np.vstack([mins, maxs])  # type: ignore[assignment]
         return extrema[:, 1:]
 
     def _get_ndim(self) -> int:
@@ -274,7 +274,7 @@ class Tracks(Layer):
 
         return
 
-    def _get_value(self, position) -> Optional[int]:
+    def _get_value(self, position) -> int | None:
         """Value of the data at a position in data coordinates.
 
         Use a kd-tree to lookup the ID of the nearest tree.
@@ -366,7 +366,7 @@ class Tracks(Layer):
         return data[:, (2, 1, 0)]  # z, y, x -> x, y, z
 
     @property
-    def current_time(self) -> Optional[int]:
+    def current_time(self) -> int | None:
         """current time according to the first dimension"""
         # TODO(arl): get the correct index here
         time_step = self._data_slice.point[0]
@@ -432,7 +432,7 @@ class Tracks(Layer):
     @features.setter
     def features(
         self,
-        features: Union[dict[str, np.ndarray], pd.DataFrame],
+        features: dict[str, np.ndarray] | pd.DataFrame,
     ) -> None:
         self._manager.features = features
         self._check_color_by_in_features()
@@ -454,12 +454,12 @@ class Tracks(Layer):
         return list(self.properties.keys())
 
     @property
-    def graph(self) -> Optional[dict[int, list[int]]]:
+    def graph(self) -> dict[int, list[int]] | None:
         """dict {int: list}: Graph representing associations between tracks."""
         return self._manager.graph
 
     @graph.setter
-    def graph(self, graph: dict[int, Union[int, list[int]]]) -> None:
+    def graph(self, graph: dict[int, int | list[int]]) -> None:
         """Set the track graph."""
         # Ignored type, because mypy can't handle different signatures
         # on getters and setters; see https://github.com/python/mypy/issues/3004
@@ -575,10 +575,8 @@ class Tracks(Layer):
     def colormaps_dict(self) -> dict[str, Colormap]:
         return self._colormaps_dict
 
-    # Ignored type because mypy doesn't recognise colormaps_dict as a property
-    # TODO: investigate and fix this - not sure why this is the case?
-    @colormaps_dict.setter  # type: ignore[attr-defined]
-    def colomaps_dict(self, colormaps_dict: dict[str, Colormap]) -> None:
+    @colormaps_dict.setter
+    def colormaps_dict(self, colormaps_dict: dict[str, Colormap]) -> None:
         # validate the dictionary entries?
         self._colormaps_dict = colormaps_dict
 
@@ -609,28 +607,43 @@ class Tracks(Layer):
         self._track_colors = colormap.map(vertex_properties)
 
     @property
-    def track_connex(self) -> Optional[np.ndarray]:
+    def track_connex(self) -> np.ndarray | None:
         """vertex connections for drawing track lines"""
         return self._manager.track_connex
 
     @property
-    def track_colors(self) -> Optional[np.ndarray]:
-        """return the vertex colors according to the currently selected
-        property"""
+    def track_colors(self) -> np.ndarray | None:
+        """Return current vertex colors."""
         return self._track_colors
 
+    @track_colors.setter
+    def track_colors(self, colors: np.ndarray) -> None:
+        """Set vertex colors directly and emit corresponding event.
+
+        Parameters
+        ----------
+        colors : np.ndarray, shape (N, 4)
+            The desired color array, one color per data point. Note that the
+            data are internally lexicographically sorted first by track ID,
+            then by timepoint, so the color ordering must match this order,
+            which may not be the input order. Use `Tracks.data` to find the
+            current sorted data.
+        """
+        self._track_colors = colors
+        self.events.color_by()
+
     @property
-    def graph_connex(self) -> Optional[np.ndarray]:
+    def graph_connex(self) -> np.ndarray | None:
         """vertex connections for drawing the graph"""
         return self._manager.graph_connex
 
     @property
-    def track_times(self) -> Optional[np.ndarray]:
+    def track_times(self) -> np.ndarray | None:
         """time points associated with each track vertex"""
         return self._manager.track_times
 
     @property
-    def graph_times(self) -> Optional[np.ndarray]:
+    def graph_times(self) -> np.ndarray | None:
         """time points associated with each graph vertex"""
         return self._manager.graph_times
 
