@@ -22,11 +22,11 @@ def test_type_enforcement(list_type):
     a = list_type([1, 2, 3, 4], basetype=int)
     assert tuple(a) == (1, 2, 3, 4)
     with pytest.raises(TypeError):
-        a.append("string")
+        a.append('string')
     with pytest.raises(TypeError):
-        a.insert(0, "string")
+        a.insert(0, 'string')
     with pytest.raises(TypeError):
-        a[0] = "string"
+        a[0] = 'string'
     with pytest.raises(TypeError):
         a[0] = 1.23
 
@@ -41,7 +41,7 @@ def test_type_enforcement_with_slices(list_type):
     a[:] = list(range(10))
     with pytest.raises(TypeError):
         a[4:4] = ['hi']
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='attempt to assign sequence of size'):
         a[2:9:2] = [1, 2, 3]  # not the right length
     with pytest.raises(TypeError):  # right length, includes bad type
         a[2:9:2] = [1, 2, 3, 'a']
@@ -53,7 +53,7 @@ def test_multitype_enforcement(list_type):
     a = list_type([1, 2, 3, 4, 5.5], basetype=(int, float))
     assert tuple(a) == (1, 2, 3, 4, 5.5)
     with pytest.raises(TypeError):
-        a.append("string")
+        a.append('string')
     a.append(2)
     a.append(2.4)
 
@@ -62,7 +62,7 @@ def test_custom_lookup(list_type):
     """Test that we can get objects by non-integer index using custom lookups."""
 
     class Custom:
-        def __init__(self, name='', data=()):
+        def __init__(self, name='', data=()) -> None:
             self.name = name
             self.data = data
 
@@ -76,7 +76,7 @@ def test_custom_lookup(list_type):
     )
     # index with integer as usual
     assert a[1].name == 'hi'
-    assert a.index("hi") == 1
+    assert a.index('hi') == 1
 
     # index with string also works
     assert a['hi'] == hi
@@ -87,9 +87,9 @@ def test_custom_lookup(list_type):
     assert a[{'some': 'data'}] == dct
 
     # index still works with start/stop arguments
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='is not in list'):
         assert a.index((1, 2, 3), stop=2)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='is not in list'):
         assert a.index((1, 2, 3), start=-3, stop=-1)
 
     # contains works
@@ -113,19 +113,19 @@ def test_nested_type_enforcement():
 
     # first level
     with pytest.raises(TypeError):
-        a.append("string")
+        a.append('string')
     with pytest.raises(TypeError):
-        a.insert(0, "string")
+        a.insert(0, 'string')
     with pytest.raises(TypeError):
-        a[0] = "string"
+        a[0] = 'string'
 
     # deeply nested
     with pytest.raises(TypeError):
-        a[2, 2].append("string")
+        a[2, 2].append('string')
     with pytest.raises(TypeError):
-        a[2, 2].insert(0, "string")
+        a[2, 2].insert(0, 'string')
     with pytest.raises(TypeError):
-        a[2, 2, 0] = "string"
+        a[2, 2, 0] = 'string'
 
     # also works during instantiation
     with pytest.raises(TypeError):
@@ -137,7 +137,7 @@ def test_nested_type_enforcement():
 
 def test_nested_custom_lookup():
     class Custom:
-        def __init__(self, name=''):
+        def __init__(self, name='') -> None:
             self.name = name
 
     c = Custom()
@@ -152,10 +152,10 @@ def test_nested_custom_lookup():
     )
     # first level
     assert a[1].name == 'c1'  # index with integer as usual
-    assert a.index("c1") == 1
+    assert a.index('c1') == 1
     assert a['c1'] == c1  # index with string also works
 
     # second level
     assert a[2, 0].name == 'c2'
-    assert a.index("c2") == (2, 0)
+    assert a.index('c2') == (2, 0)
     assert a['c2'] == c2
